<?php

namespace App\Http\Controllers;

use App\Models\Subscriber;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use GuzzleHttp\Client;

class SubscribersController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        if (!$request->ajax()) {
            return response()->json([
                'message' => 'Invalid request',
            ], 400);
        }


        // custom validation error messages...
        $messages = [
            'email.required' => 'Please enter your email address.',
            'email.email' => 'Please enter a valid email address.',
            'email.unique' => 'You have already been added to the waitlist.',
            'g-recaptcha-response.required' => 'Please verify that you are not a robot.',
        ];

        // validate the request...
        $validator = Validator::make($request->all(), [
            'email' => 'required|email:rfc,dns|unique:subscribers',
            'g-recaptcha-response' => 'required',
        ], $messages);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'errors' => $validator->errors(),
            ]); // HTTP status code for unprocessable entity
        }


        // Verify reCAPTCHA response with Google
        $client = new Client();
        $response = $client->post('https://www.google.com/recaptcha/api/siteverify', [
            'form_params' => [
                'secret' => env('NOCAPTCHA_SECRET'), //
                'response' => $request->input('g-recaptcha-response'),
                'remoteip' => $request->ip()
            ]
        ]);


        $body = json_decode((string) $response->getBody());
        if (!$body->success || $body->score < 0.5) { // Check for a success response and a minimum score threshold
            return response()->json([
                'success' => false,
                'errors' => ['recaptcha' => ['reCAPTCHA verification failed.']],
            ], 422);
        }

        // create a new subscriber instance...
        $subscriber = new Subscriber();
        $subscriber->email = $request->email;
        $subscriber->save();

        // return a response...
            return response()->json([
                'success' => true,
                'message' => 'You have been added to the waitlist!',
            ]);

    }

    /**
     * Display the specified resource.
     */
    public function show(Subscriber $subscriber)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Subscriber $subscriber)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Subscriber $subscriber)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Subscriber $subscriber)
    {
        //
    }
}
